pub trait CacheManager: Send + Sync + 'static {
    // Required methods
    fn get<'life0, 'life1, 'life2, 'async_trait>(
&'life0 self,
method: &'life1 str,
url: &'life2 Url
) -> Pin<Box<dyn Future<Output = Result<Option<(HttpResponse, CachePolicy)>>> + Send + 'async_trait>>
where Self: 'async_trait,
'life0: 'async_trait,
'life1: 'async_trait,
'life2: 'async_trait
; fn put<'life0, 'life1, 'life2, 'async_trait>(
&'life0 self,
method: &'life1 str,
url: &'life2 Url,
res: HttpResponse,
policy: CachePolicy
) -> Pin<Box<dyn Future<Output = Result<HttpResponse>> + Send + 'async_trait>>
where Self: 'async_trait,
'life0: 'async_trait,
'life1: 'async_trait,
'life2: 'async_trait
; fn delete<'life0, 'life1, 'life2, 'async_trait>(
&'life0 self,
method: &'life1 str,
url: &'life2 Url
) -> Pin<Box<dyn Future<Output = Result<()>> + Send + 'async_trait>>
where Self: 'async_trait,
'life0: 'async_trait,
'life1: 'async_trait,
'life2: 'async_trait
; }
A trait providing methods for storing, reading, and removing cache records.

Required Methods

source

fn get<'life0, 'life1, 'life2, 'async_trait>(
&'life0 self,
method: &'life1 str,
url: &'life2 Url
) -> Pin<Box<dyn Future<Output = Result<Option<(HttpResponse, CachePolicy)>>> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
'life1: 'async_trait,
'life2: 'async_trait,

Attempts to pull a cached response and related policy from cache.

source

fn put<'life0, 'life1, 'life2, 'async_trait>(
&'life0 self,
method: &'life1 str,
url: &'life2 Url,
res: HttpResponse,
policy: CachePolicy
) -> Pin<Box<dyn Future<Output = Result<HttpResponse>> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
'life1: 'async_trait,
'life2: 'async_trait,

Attempts to cache a response and related policy.

source

fn delete<'life0, 'life1, 'life2, 'async_trait>(
&'life0 self,
method: &'life1 str,
url: &'life2 Url
) -> Pin<Box<dyn Future<Output = Result<()>> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
'life1: 'async_trait,
'life2: 'async_trait,

Attempts to remove a record from cache.

Implementors